Module iter

Module iter 

GPU-compatible iterators.

Structs

StepRng
A custom replacement for (a..b).step_by(c). This is useful as the iterator combinator adds some early-exists that break uniform control flow; this is incompatible with using barriers when targetting WebGpu on the browser.