Module macros

Module macros 

Re-exports of spirv_std_macros and khal_derive::spirv_bindgen.

Macros

Image
A macro for creating SPIR-V OpTypeImage types. Always produces a spirv_std::image::Image<...> type.
debug_printf
Print a formatted string using the debug printf extension.
debug_printfln
Similar to debug_printf but appends a newline to the format string.

Attribute Macros

gpu_only
Marks a function as runnable only on the GPU, and will panic on CPU platforms.
spirv
Replaces all (nested) occurrences of the #[spirv(..)] attribute with #[cfg_attr(target_arch="spirv", rust_gpu::spirv(..))].
spirv_bindgen
spirv_recursive_for_testing
For testing only! Is not reexported in spirv-std, but reachable via spirv_std::macros::spirv_recursive_for_testing.

Derive Macros

ScalarComposite