pub enum Scope {
CrossDevice = 0,
Device = 1,
Workgroup = 2,
Subgroup = 3,
Invocation = 4,
QueueFamily = 5,
}Expand description
Specification for how large of a scope some instructions should operate on - used when calling functions that take a configurable scope.
Variants
CrossDevice = 0
Crosses multiple devices.
Device = 1
The current device.
Workgroup = 2
The current workgroup.
Subgroup = 3
The current subgroup.
Invocation = 4
The current invocation.
QueueFamily = 5
The current queue family.